======================
About django-scaffold
======================

A Reusable application providing a generic section/subsection hierarchy in Django. 

Aims to solve a common problem: you're building a site that needs sections and 
subsections and you not only need to be able to manage that hierarchy, but 
also hang other content off of it.

Requirements
--------------

* `Django <http://djangoproject.com>`_   (1.3 or higher)
* `django-treebeard <https://tabo.pe/projects/django-treebeard/>`_.


Django-scaffolding uses the following javascript libraries (these are included in project):

* `jQuery <http://jquery.com>`_
* `jQuery UI <http://jqueryui.com/>`_
* `jstree <http://jstree.com/>`_

This project is licensed under a BSD License. Admin UI inspired by 
`django CMS <http://www.django-cms.org>`_.

.. image:: http://github.com/mazelife/django-scaffold/raw/master/docs/source/_static/menu.png
